==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/WebhookTokenAuthenticatorFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class WebhookTokenAuthenticatorFluentImpl<A extends io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent<A>{
  public WebhookTokenAuthenticatorFluentImpl() {
  }
  public WebhookTokenAuthenticatorFluentImpl(io.fabric8.openshift.api.model.WebhookTokenAuthenticator instance) {
    this.withKubeConfig(instance.getKubeConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder kubeConfig;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildKubeConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getKubeConfig() {
    return this.kubeConfig!=null?this.kubeConfig.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildKubeConfig() {
    return this.kubeConfig!=null?this.kubeConfig.build():null;
  }
  public A withKubeConfig(io.fabric8.openshift.api.model.SecretNameReference kubeConfig) {
    _visitables.get("kubeConfig").remove(this.kubeConfig);
    if (kubeConfig!=null){ this.kubeConfig= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(kubeConfig); _visitables.get("kubeConfig").add(this.kubeConfig);} return (A) this;
  }
  public java.lang.Boolean hasKubeConfig() {
    return this.kubeConfig != null;
  }
  public A withNewKubeConfig(java.lang.String name) {
    return (A)withKubeConfig(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> withNewKubeConfig() {
    return new io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluentImpl.KubeConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> withNewKubeConfigLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluentImpl.KubeConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> editKubeConfig() {
    return withNewKubeConfigLike(getKubeConfig());
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> editOrNewKubeConfig() {
    return withNewKubeConfigLike(getKubeConfig() != null ? getKubeConfig(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> editOrNewKubeConfigLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewKubeConfigLike(getKubeConfig() != null ? getKubeConfig(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WebhookTokenAuthenticatorFluentImpl that = (WebhookTokenAuthenticatorFluentImpl) o;
    if (kubeConfig != null ? !kubeConfig.equals(that.kubeConfig) :that.kubeConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(kubeConfig,  additionalProperties,  super.hashCode());
  }
  public class KubeConfigNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<N>> implements io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    KubeConfigNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    KubeConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) WebhookTokenAuthenticatorFluentImpl.this.withKubeConfig(builder.build());
    }
    public N endKubeConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/WebhookTokenAuthenticatorFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class WebhookTokenAuthenticatorFluentImpl<A extends io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent<A>{
  public WebhookTokenAuthenticatorFluentImpl() {
  }
  public WebhookTokenAuthenticatorFluentImpl(io.fabric8.openshift.api.model.WebhookTokenAuthenticator instance) {
    this.withKubeConfig(instance.getKubeConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder kubeConfig;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildKubeConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getKubeConfig() {
    return this.kubeConfig!=null?this.kubeConfig.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildKubeConfig() {
    return this.kubeConfig!=null?this.kubeConfig.build():null;
  }
  public A withKubeConfig(io.fabric8.openshift.api.model.SecretNameReference kubeConfig) {
    _visitables.get("kubeConfig").remove(this.kubeConfig);
    if (kubeConfig!=null){ this.kubeConfig= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(kubeConfig); _visitables.get("kubeConfig").add(this.kubeConfig);} return (A) this;
  }
  public java.lang.Boolean hasKubeConfig() {
    return this.kubeConfig != null;
  }
  public A withNewKubeConfig(java.lang.String name) {
    return (A)withKubeConfig(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> withNewKubeConfig() {
    return new io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluentImpl.KubeConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> withNewKubeConfigLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluentImpl.KubeConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> editKubeConfig() {
    return withNewKubeConfigLike(getKubeConfig());
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> editOrNewKubeConfig() {
    return withNewKubeConfigLike(getKubeConfig() != null ? getKubeConfig(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<A> editOrNewKubeConfigLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewKubeConfigLike(getKubeConfig() != null ? getKubeConfig(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WebhookTokenAuthenticatorFluentImpl that = (WebhookTokenAuthenticatorFluentImpl) o;
    if (kubeConfig != null ? !kubeConfig.equals(that.kubeConfig) :that.kubeConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(kubeConfig,  additionalProperties,  super.hashCode());
  }
  public class KubeConfigNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<N>> implements io.fabric8.openshift.api.model.WebhookTokenAuthenticatorFluent.KubeConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    KubeConfigNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    KubeConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) WebhookTokenAuthenticatorFluentImpl.this.withKubeConfig(builder.build());
    }
    public N endKubeConfig() {
      return and();
    }
    
  }
  
}
